@@ -626,9 +626,13 @@ static int snd_pcm_dmix_pause(snd_pcm_t *pcm, int enable)
 
 static snd_pcm_sframes_t snd_pcm_dmix_rewind(snd_pcm_t *pcm, snd_pcm_uframes_t frames)
 {
+#if 0
 	/* FIXME: substract samples from the mix ring buffer, too? */
 	snd_pcm_mmap_appl_backward(pcm, frames);
 	return frames;
+#else
+	return -EIO;
+#endif
 }
 
 static snd_pcm_sframes_t snd_pcm_dmix_forward(snd_pcm_t *pcm, snd_pcm_uframes_t frames)
@@ -1215,6 +1219,14 @@ int _snd_pcm_dmix_open(snd_pcm_t **pcmp, const char *name,
 	if (err < 0)
 		return err;
 
+	/* sorry, limited features */
+        if (params.format != SND_PCM_FORMAT_S16 &&
+            params.format != SND_PCM_FORMAT_S32) {
+		SNDERR("invalid format, specify s16 or s32");
+		snd_config_delete(sconf);
+		return -EINVAL;
+	}
+
 	params.period_size = psize;
 	params.buffer_size = bsize;
 
