@@ -200,9 +200,9 @@ struct _snd_pcm {
 	snd_pcm_rbptr_t appl;
 	snd_pcm_rbptr_t hw;
 	snd_pcm_uframes_t min_align;
-	int mmap_rw;
-	int shadow_mmap;
-	int donot_close;
+	int mmap_rw: 1,
+	    mmap_shadow: 1,
+	    donot_close: 1;
 	snd_pcm_channel_info_t *mmap_channels;
 	snd_pcm_channel_area_t *running_areas;
 	snd_pcm_channel_area_t *stopped_areas;
@@ -787,3 +787,15 @@ int snd_pcm_hw_open_fd(snd_pcm_t **pcmp, const char *name, int fd, int mmap_emul
 	 (1U << SND_PCM_FORMAT_FLOAT_BE) | \
 	 (1U << SND_PCM_FORMAT_FLOAT64_LE) | \
 	 (1U << SND_PCM_FORMAT_FLOAT64_BE)) }
+
+
+typedef union snd_tmp_float {
+	float f;
+	int32_t i;
+} snd_tmp_float_t;
+
+typedef union snd_tmp_double {
+	double d;
+	int64_t l;
+} snd_tmp_double_t;
+
