@@ -795,6 +795,8 @@ int snd_is_local(struct hostent *hent)
 	
 	conf.ifc_len = numreqs * sizeof(struct ifreq);
 	conf.ifc_buf = malloc((unsigned int) conf.ifc_len);
+	if (! conf.ifc_buf)
+		return -ENOMEM;
 	while (1) {
 		err = ioctl(s, SIOCGIFCONF, &conf);
 		if (err < 0) {
@@ -806,6 +808,8 @@ int snd_is_local(struct hostent *hent)
 		numreqs *= 2;
 		conf.ifc_len = numreqs * sizeof(struct ifreq);
 		conf.ifc_buf = realloc(conf.ifc_buf, (unsigned int) conf.ifc_len);
+		if (! conf.ifc_buf)
+			return -ENOMEM;
 	}
 	numreqs = conf.ifc_len / sizeof(struct ifreq);
 	for (i = 0; i < numreqs; ++i) {
